pub struct RepoContext { /* private fields */ }Expand description
A resolved catalog entry. The root is fixed at startup and requests only ever resolve this entry by its validated id.
Implementations
Sourceimpl RepoContext
impl RepoContext